Index: prdatasets/abalone.m
===================================================================
--- prdatasets/abalone.m	(revision 148)
+++ prdatasets/abalone.m	(revision 150)
@@ -13,8 +13,8 @@
 %categories. They may be converted to N new real features by CAT2REAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = abalone
Index: prdatasets/adult.m
===================================================================
--- prdatasets/adult.m	(revision 148)
+++ prdatasets/adult.m	(revision 150)
@@ -17,8 +17,8 @@
 %removed. Use VAL=NaN to avoid this. For other options see MISVAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL, MISVAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function varargout = adult(val)
Index: prdatasets/annealing.m
===================================================================
--- prdatasets/annealing.m	(revision 148)
+++ prdatasets/annealing.m	(revision 150)
@@ -17,8 +17,8 @@
 %removed. Use VAL=NaN to avoid this. For other options see MISVAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL, MISVAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function varargout = annealing(val)
Index: prdatasets/arcene.m
===================================================================
--- prdatasets/arcene.m	(revision 148)
+++ prdatasets/arcene.m	(revision 150)
@@ -16,8 +16,8 @@
 %merged with a large number of random features. See the dataset <a href="http://archive.ics.uci.edu/ml/datasets/Arcene">website</a>.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function [a,b,c] = arcene
Index: prdatasets/arrhythmia.m
===================================================================
--- prdatasets/arrhythmia.m	(revision 148)
+++ prdatasets/arrhythmia.m	(revision 150)
@@ -11,8 +11,8 @@
 % is desired, use one of the options in MISVAL for VAL.
 %
-% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 % PRTOOLS, DATASETS, MISVAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = arrhythmia(val)
Index: prdatasets/audiology.m
===================================================================
--- prdatasets/audiology.m	(revision 148)
+++ prdatasets/audiology.m	(revision 150)
@@ -17,8 +17,8 @@
 %removed. Use VAL=NaN to avoid this. For other options see MISVAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL, MISVAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function varargout = audiology(val)
Index: prdatasets/australian_sl.m
===================================================================
--- prdatasets/australian_sl.m	(revision 148)
+++ prdatasets/australian_sl.m	(revision 150)
@@ -13,8 +13,8 @@
 %categories. They may be converted to N new real features by CAT2REAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = australian_sl
Index: prdatasets/auto_mpg.m
===================================================================
--- prdatasets/auto_mpg.m	(revision 148)
+++ prdatasets/auto_mpg.m	(revision 150)
@@ -11,5 +11,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/balance_scale.m
===================================================================
--- prdatasets/balance_scale.m	(revision 148)
+++ prdatasets/balance_scale.m	(revision 150)
@@ -13,8 +13,8 @@
 %It may be converted to 3 new real features by CAT2REAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = balance_scale
Index: prdatasets/balloons.m
===================================================================
--- prdatasets/balloons.m	(revision 148)
+++ prdatasets/balloons.m	(revision 150)
@@ -14,5 +14,5 @@
 %routines expecting continuous features.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %DATASETS
 
Index: prdatasets/biomed.m
===================================================================
--- prdatasets/biomed.m	(revision 148)
+++ prdatasets/biomed.m	(revision 150)
@@ -15,8 +15,8 @@
 % Just the original features 3, 5, 6, 7 and 8 are used.
 %
-% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 % PRTOOLS, DATASETS, MISVAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = biomed(val)
Index: prdatasets/breast.m
===================================================================
--- prdatasets/breast.m	(revision 148)
+++ prdatasets/breast.m	(revision 150)
@@ -15,8 +15,8 @@
 % is desired, use one of the options in MISVAL for VAL.
 %
-% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 % PRTOOLS, DATASETS, MISVAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = breast(val)
Index: prdatasets/car.m
===================================================================
--- prdatasets/car.m	(revision 148)
+++ prdatasets/car.m	(revision 150)
@@ -9,8 +9,8 @@
 % The instances completely cover the attribute space.
 %
-% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 % PRTOOLS, DATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = car
Index: prdatasets/cbands.m
===================================================================
--- prdatasets/cbands.m	(revision 148)
+++ prdatasets/cbands.m	(revision 150)
@@ -9,5 +9,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/census.m
===================================================================
--- prdatasets/census.m	(revision 148)
+++ prdatasets/census.m	(revision 150)
@@ -17,8 +17,8 @@
 %removed. Use VAL=NaN to avoid this. For other options see MISVAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL, MISVAL,ADULT
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function varargout = census(val)
Index: prdatasets/chromo.m
===================================================================
--- prdatasets/chromo.m	(revision 148)
+++ prdatasets/chromo.m	(revision 150)
@@ -6,5 +6,5 @@
 % thresholded chromosomes. This technique is outdated.
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/cmc.m
===================================================================
--- prdatasets/cmc.m	(revision 148)
+++ prdatasets/cmc.m	(revision 150)
@@ -13,8 +13,8 @@
 %It may be converted to 4 new real features by CAT2REAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = cmc
Index: prdatasets/credit.m
===================================================================
--- prdatasets/credit.m	(revision 148)
+++ prdatasets/credit.m	(revision 150)
@@ -15,8 +15,8 @@
 %There are missing values, coded by NaNs. They may be handled by MISVAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, MISVAL, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = credit
Index: prdatasets/cylinderbands.m
===================================================================
--- prdatasets/cylinderbands.m	(revision 148)
+++ prdatasets/cylinderbands.m	(revision 150)
@@ -15,13 +15,13 @@
 %There are missing values, coded by NaNs. They may be handled by MISVAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, MISVAL, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = cylinderbands
 
 % UCI dataset is irregulary formatted.
-% Load modified data from 37steps.
-a = pr_download_uci('Cylinder+Bands','http://37steps.com/data/prdatasets/cylinderbands.dat');
+% Load modified data from prtools website.
+a = pr_download_uci('Cylinder+Bands','http://prtools.tudelft.nl/prdatasets/cylinderbands.dat');
 a = setname(a,'Cylinder Bands Dataset');
Index: prdatasets/emim.m
===================================================================
--- prdatasets/emim.m	(revision 148)
+++ prdatasets/emim.m	(revision 150)
@@ -16,5 +16,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5038, 2600 GA Delft, The Netherlands
Index: prdatasets/flowcyto.m
===================================================================
--- prdatasets/flowcyto.m	(revision 148)
+++ prdatasets/flowcyto.m	(revision 150)
@@ -19,5 +19,5 @@
 % PRTOOLS, DATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 
@@ -32,5 +32,5 @@
 end
 
-d = pr_getdata('http://37steps.com/data/prdatasets/FlowCyto_sort.mat',5);
+d = pr_getdata('http://prtools.tudelft.nl/prdatasets/FlowCyto_sort.mat',5);
 
 a = cell(1,numel(n));
Index: prdatasets/german_num_sl.m
===================================================================
--- prdatasets/german_num_sl.m	(revision 148)
+++ prdatasets/german_num_sl.m	(revision 150)
@@ -13,8 +13,8 @@
 %STATLOG_GERMAN_NUM
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL, GERMAN_SL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = german_num_sl
Index: prdatasets/german_sl.m
===================================================================
--- prdatasets/german_sl.m	(revision 148)
+++ prdatasets/german_sl.m	(revision 150)
@@ -14,8 +14,8 @@
 %There is a numeric version of this dataset: STATLOG_GERMAN_NUM
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL, GERMAN_NUM_SL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = german_sl
Index: prdatasets/glass.m
===================================================================
--- prdatasets/glass.m	(revision 148)
+++ prdatasets/glass.m	(revision 150)
@@ -16,5 +16,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/haberman.m
===================================================================
--- prdatasets/haberman.m	(revision 148)
+++ prdatasets/haberman.m	(revision 150)
@@ -10,8 +10,8 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = haberman
Index: prdatasets/heart.m
===================================================================
--- prdatasets/heart.m	(revision 148)
+++ prdatasets/heart.m	(revision 150)
@@ -11,8 +11,8 @@
 % is desired, use one of the options in MISVAL.
 %
-% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 % PRTOOLS, DATASETS, MISVAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = heart(val)
Index: prdatasets/heart_sl.m
===================================================================
--- prdatasets/heart_sl.m	(revision 148)
+++ prdatasets/heart_sl.m	(revision 150)
@@ -10,8 +10,8 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = heart_sl
Index: prdatasets/hepatitis.m
===================================================================
--- prdatasets/hepatitis.m	(revision 148)
+++ prdatasets/hepatitis.m	(revision 150)
@@ -11,8 +11,8 @@
 % is desired, use one of the options in MISVAL.
 %
-% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+% SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 % PRTOOLS, DATASETS, MISVAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = hepatitis(val)
Index: prdatasets/imox.m
===================================================================
--- prdatasets/imox.m	(revision 148)
+++ prdatasets/imox.m	(revision 150)
@@ -20,5 +20,5 @@
 % See also DATASETS, PRDATASETS, X80
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/imsegment.m
===================================================================
--- prdatasets/imsegment.m	(revision 148)
+++ prdatasets/imsegment.m	(revision 150)
@@ -11,8 +11,8 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function [a,b] = imsegment
Index: prdatasets/imsegment_sl.m
===================================================================
--- prdatasets/imsegment_sl.m	(revision 148)
+++ prdatasets/imsegment_sl.m	(revision 150)
@@ -12,8 +12,8 @@
 %This dataset is very similar to the IMSEGMENT dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, IMSEGMENT
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = imsegment_sl
Index: prdatasets/ionosphere.m
===================================================================
--- prdatasets/ionosphere.m	(revision 148)
+++ prdatasets/ionosphere.m	(revision 150)
@@ -11,5 +11,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/kimia.m
===================================================================
--- prdatasets/kimia.m	(revision 148)
+++ prdatasets/kimia.m	(revision 150)
@@ -11,5 +11,5 @@
 % See also DATASETS, PRDATASETS, PRDATAFILES, PRDATAFILES/KIMIA_IMAGES
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/lena.m
===================================================================
--- prdatasets/lena.m	(revision 148)
+++ prdatasets/lena.m	(revision 150)
@@ -8,5 +8,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/letter.m
===================================================================
--- prdatasets/letter.m	(revision 148)
+++ prdatasets/letter.m	(revision 150)
@@ -10,5 +10,5 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 
 function a = letter
Index: prdatasets/liver.m
===================================================================
--- prdatasets/liver.m	(revision 148)
+++ prdatasets/liver.m	(revision 150)
@@ -9,5 +9,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/magic04.m
===================================================================
--- prdatasets/magic04.m	(revision 148)
+++ prdatasets/magic04.m	(revision 150)
@@ -10,8 +10,8 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = magic04
Index: prdatasets/malaysia.m
===================================================================
--- prdatasets/malaysia.m	(revision 148)
+++ prdatasets/malaysia.m	(revision 150)
@@ -8,5 +8,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5038, 2600 GA Delft, The Netherlands
Index: prdatasets/mammograph.m
===================================================================
--- prdatasets/mammograph.m	(revision 148)
+++ prdatasets/mammograph.m	(revision 150)
@@ -12,8 +12,8 @@
 %There are missing values, coded by NaNs. They may be handled by MISVAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, MISVAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = mammograph
Index: prdatasets/mfeat.m
===================================================================
--- prdatasets/mfeat.m	(revision 148)
+++ prdatasets/mfeat.m	(revision 150)
@@ -24,5 +24,5 @@
 % MFEAT_PIX, MFEAT_ZER
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/mfeat_all.m
===================================================================
--- prdatasets/mfeat_all.m	(revision 148)
+++ prdatasets/mfeat_all.m	(revision 150)
@@ -19,5 +19,5 @@
 % See also DATASETS, PRDATASETS, 
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/mfeat_fac.m
===================================================================
--- prdatasets/mfeat_fac.m	(revision 148)
+++ prdatasets/mfeat_fac.m	(revision 150)
@@ -8,5 +8,5 @@
 % See also DATASETS, PRDATASETS, MFEAT
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/mfeat_fou.m
===================================================================
--- prdatasets/mfeat_fou.m	(revision 148)
+++ prdatasets/mfeat_fou.m	(revision 150)
@@ -7,5 +7,5 @@
 % See also DATASETS, PRDATASETS, MFEAT
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/mfeat_kar.m
===================================================================
--- prdatasets/mfeat_kar.m	(revision 148)
+++ prdatasets/mfeat_kar.m	(revision 150)
@@ -7,5 +7,5 @@
 % See also DATASETS, PRDATASETS, MFEAT
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/mfeat_mor.m
===================================================================
--- prdatasets/mfeat_mor.m	(revision 148)
+++ prdatasets/mfeat_mor.m	(revision 150)
@@ -7,5 +7,5 @@
 % See also DATASETS, PRDATASETS, MFEAT
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/mfeat_pix.m
===================================================================
--- prdatasets/mfeat_pix.m	(revision 148)
+++ prdatasets/mfeat_pix.m	(revision 150)
@@ -8,5 +8,5 @@
 % See also DATASETS, PRDATASETS, MFEAT
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/mfeat_zer.m
===================================================================
--- prdatasets/mfeat_zer.m	(revision 148)
+++ prdatasets/mfeat_zer.m	(revision 150)
@@ -7,5 +7,5 @@
 % See also DATASETS, PRDATASETS, MFEAT
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/mnist.m
===================================================================
--- prdatasets/mnist.m	(revision 148)
+++ prdatasets/mnist.m	(revision 150)
@@ -8,5 +8,5 @@
 % The trainset has 60000 digits and the testset 1000.
 %
-% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://yann.lecun.com/exdb/mnist/">Original Website</a>
+% SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://yann.lecun.com/exdb/mnist/">Original Website</a>
 % PRTOOLS, DATASETS, SHOW
 
@@ -19,6 +19,6 @@
 if isempty(varargout{1})
   
-  a = pr_getdata(['http://37steps.com/data/prdatafiles/MNIST_train.zip'],42,'mnist_train','',1);
-  b = pr_getdata(['http://37steps.com/data/prdatafiles/MNIST_test.zip'],[],'mnist_test','',0);
+  a = pr_getdata(['http://prtools.tudelft.nl/prdatafiles/MNIST_train.zip'],42,'mnist_train','',1);
+  b = pr_getdata(['http://prtools.tudelft.nl/prdatafiles/MNIST_test.zip'],[],'mnist_test','',0);
   % Note that these are datafiles
   user.desc = ['This is the trainset of MNIST.'];
Index: prdatasets/mnist8.m
===================================================================
--- prdatasets/mnist8.m	(revision 148)
+++ prdatasets/mnist8.m	(revision 150)
@@ -13,5 +13,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/nist16.m
===================================================================
--- prdatasets/nist16.m	(revision 148)
+++ prdatasets/nist16.m	(revision 150)
@@ -8,5 +8,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/nist32.m
===================================================================
--- prdatasets/nist32.m	(revision 148)
+++ prdatasets/nist32.m	(revision 150)
@@ -7,5 +7,5 @@
 % See also DATASETS, PRDATASETS, NIST16
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/optdigits.m
===================================================================
--- prdatasets/optdigits.m	(revision 148)
+++ prdatasets/optdigits.m	(revision 150)
@@ -11,8 +11,8 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function [a,b] = optdigits
Index: prdatasets/pendigits.m
===================================================================
--- prdatasets/pendigits.m	(revision 148)
+++ prdatasets/pendigits.m	(revision 150)
@@ -11,5 +11,5 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 
 function [a,b] = pendigits
Index: prdatasets/pr_download_uci.m
===================================================================
--- prdatasets/pr_download_uci.m	(revision 148)
+++ prdatasets/pr_download_uci.m	(revision 150)
@@ -26,7 +26,7 @@
 %         {'segmentation.data','segmentation.test'},opt);
 %
-% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>
-
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>
+
+% Copyright: R.P.W. Duin 
 
 function varargout = pr_download_uci(name,varargin)
Index: prdatasets/pr_dset_align.m
===================================================================
--- prdatasets/pr_dset_align.m	(revision 148)
+++ prdatasets/pr_dset_align.m	(revision 150)
@@ -6,8 +6,8 @@
 % this routine they might be coded differently.
 %
-% SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>
+% SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>
 % DATASETS, SETFEATDOM, FEATTYPES, DSET2CELL, CELL2DSET
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function varargout = pr_dset_align(varargin)
Index: prdatasets/pr_getdata.m
===================================================================
--- prdatasets/pr_getdata.m	(revision 148)
+++ prdatasets/pr_getdata.m	(revision 150)
@@ -21,8 +21,8 @@
 % is constucted and returned to the user.
 %
-% SEE ALSO (<a href="http://37steps.com/prhtml/37tools.html">37tools Contents</a>)
+% SEE ALSO
 % DATASETS, DATAFILES
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function out = pr_getdata(varargin)
Index: prdatasets/ringnorm.m
===================================================================
--- prdatasets/ringnorm.m	(revision 148)
+++ prdatasets/ringnorm.m	(revision 150)
@@ -13,5 +13,5 @@
 % See also DATASETS, PRDATASETS, TWONORM
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/satellite.m
===================================================================
--- prdatasets/satellite.m	(revision 148)
+++ prdatasets/satellite.m	(revision 150)
@@ -11,5 +11,5 @@
 % See also DATASETS, PRDATASETS, SOYBEAN1
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/satellite_sl.m
===================================================================
--- prdatasets/satellite_sl.m	(revision 148)
+++ prdatasets/satellite_sl.m	(revision 150)
@@ -13,8 +13,8 @@
 %This dataset is identical to the SATELLITE dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SATELLITE
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function [a,b] = satellite_sl
Index: prdatasets/shuttle_sl.m
===================================================================
--- prdatasets/shuttle_sl.m	(revision 148)
+++ prdatasets/shuttle_sl.m	(revision 150)
@@ -11,13 +11,13 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function [a,b] = shuttle_sl
 
-url1 = 'http://37steps.com/data/prdatasets/shuttle.zip';
-url2 = 'http://37steps.com/data/prdatasets/shuttle.tst';
+url1 = 'http://prtools.tudelft.nl/prdatasets/shuttle.zip';
+url2 = 'http://prtools.tudelft.nl/prdatasets/shuttle.tst';
 opt.dsetname = 'Statlog Shuttle';
 [a,b] = pr_download_uci('Statlog+(Shuttle)',{url1,url2},[],[],[],[],[],' ');
Index: prdatasets/soybean1.m
===================================================================
--- prdatasets/soybean1.m	(revision 148)
+++ prdatasets/soybean1.m	(revision 150)
@@ -8,5 +8,5 @@
 % See also DATASETS, PRDATASETS, SOYBEAN2
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/soybean2.m
===================================================================
--- prdatasets/soybean2.m	(revision 148)
+++ prdatasets/soybean2.m	(revision 150)
@@ -8,5 +8,5 @@
 % See also DATASETS, PRDATASETS, SOYBEAN1
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/spambase.m
===================================================================
--- prdatasets/spambase.m	(revision 148)
+++ prdatasets/spambase.m	(revision 150)
@@ -12,8 +12,8 @@
 %There are no missing values found in the dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = spambase
Index: prdatasets/spectf.m
===================================================================
--- prdatasets/spectf.m	(revision 148)
+++ prdatasets/spectf.m	(revision 150)
@@ -11,8 +11,8 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS 
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function [a,b] = spectf
Index: prdatasets/spectrometer.m
===================================================================
--- prdatasets/spectrometer.m	(revision 148)
+++ prdatasets/spectrometer.m	(revision 150)
@@ -19,8 +19,8 @@
 %Remove them by A = REMCLASS(A,N) with, e.g., N = 7.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, REMCLASS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = spectrometer
Index: prdatasets/teachassist.m
===================================================================
--- prdatasets/teachassist.m	(revision 148)
+++ prdatasets/teachassist.m	(revision 150)
@@ -13,8 +13,8 @@
 %categories. They may be converted to N new real features by CAT2REAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = teachassist
Index: prdatasets/texturel.m
===================================================================
--- prdatasets/texturel.m	(revision 148)
+++ prdatasets/texturel.m	(revision 150)
@@ -15,5 +15,5 @@
 % See also DATASETS, PRDATASETS, TEXTURET
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/texturet.m
===================================================================
--- prdatasets/texturet.m	(revision 148)
+++ prdatasets/texturet.m	(revision 150)
@@ -15,5 +15,5 @@
 % See also DATASETS, PRDATASETS, TEXTUREL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/tic_tac_toe.m
===================================================================
--- prdatasets/tic_tac_toe.m	(revision 148)
+++ prdatasets/tic_tac_toe.m	(revision 150)
@@ -13,8 +13,8 @@
 %categories. They may be converted to N new real features by CAT2REAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = tic_tac_toe
Index: prdatasets/twonorm.m
===================================================================
--- prdatasets/twonorm.m	(revision 148)
+++ prdatasets/twonorm.m	(revision 150)
@@ -13,5 +13,5 @@
 % See also DATASETS, PRDATASETS, RINGNORM
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/waveform1.m
===================================================================
--- prdatasets/waveform1.m	(revision 148)
+++ prdatasets/waveform1.m	(revision 150)
@@ -15,5 +15,5 @@
 %Group: Belmont, California. (see pages 43-49). 
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 
 function a = waveform1
@@ -21,5 +21,5 @@
 % UCI data is Z-compressed. No Matlab command found for uncompressing.
 % Load zipped data from PRTools.
-url = 'http://37steps.com/data/prdatasets/waveform.zip';
+url = 'http://prtools.tudelft.nl/prdatasets/waveform.zip';
 a = pr_download_uci('Waveform+Database+Generator+(Version+1)',url);
 a = setname(a,'Simple Waveform Data');
Index: prdatasets/waveform2.m
===================================================================
--- prdatasets/waveform2.m	(revision 148)
+++ prdatasets/waveform2.m	(revision 150)
@@ -15,5 +15,5 @@
 %Group: Belmont, California. (see pages 43-49). 
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 
 function [a,b] = waveform2
@@ -21,5 +21,5 @@
 % UCI data is Z-compressed. No Matlab command found for uncompressing.
 % Load zipped data from PRTools.
-url = 'http://37steps.com/data/prdatasets/waveform-+noise.zip';
+url = 'http://prtools.tudelft.nl/prdatasets/waveform-+noise.zip';
 a = pr_download_uci('Waveform+Database+Generator+(Version+2)',url);
 a = setname(a,'Advanced Waveform Data');
Index: prdatasets/wine.m
===================================================================
--- prdatasets/wine.m	(revision 148)
+++ prdatasets/wine.m	(revision 150)
@@ -8,5 +8,5 @@
 % See also DATASETS, PRDATASETS
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 % Faculty EWI, Delft University of Technology
 % P.O. Box 5031, 2600 GA Delft, The Netherlands
Index: prdatasets/yeast.m
===================================================================
--- prdatasets/yeast.m	(revision 148)
+++ prdatasets/yeast.m	(revision 150)
@@ -13,8 +13,8 @@
 %the name 'sequence'.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = yeast
Index: prdatasets/zoo.m
===================================================================
--- prdatasets/zoo.m	(revision 148)
+++ prdatasets/zoo.m	(revision 150)
@@ -13,8 +13,8 @@
 %The feature names can be retrieved by GETFEATLAB(A).
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, GETIDENT, GETFEATLAB
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = zoo

Index: prdatasets/connect4.m
===================================================================
--- prdatasets/connect4.m	(revision 148)
+++ prdatasets/connect4.m	(revision 150)
@@ -13,14 +13,14 @@
 %categories. They may be converted to N new real features by CAT2REAL.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %PRTOOLS, DATASETS, SETFEATDOM, FEATTYPES, CAT2REAL
 
-% Copyright: R.P.W. Duin, r.p.w.duin@37steps.com
+% Copyright: R.P.W. Duin 
 
 function a = connect4
 
 % UCI data is Z-compressed. No Matlab command foud for uncompressing.
-% Load uncompressed data from 37steps.
-a = pr_download_uci('Connect-4','http://37steps.com/data/prdatasets/connect-4.data',[],[],6);
+% Load uncompressed data from prtools website.
+a = pr_download_uci('Connect-4','http://prtools.tudelft.nl/prdatasets/connect-4.data',[],[],6);
 a = setname(a,'Connect-4 Dataset');
 
Index: prdatasets/isolet.m
===================================================================
--- prdatasets/isolet.m	(revision 148)
+++ prdatasets/isolet.m	(revision 150)
@@ -11,12 +11,12 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 
 function [a,b] = isolet
 
 % UCI data is Z-compressed. No Matlab command found for uncompressing.
-% Load zipped data from 37steps.
-url1 = 'http://37steps.com/data/prdatasets/isolet1+2+3+4.zip';
-url2 = 'http://37steps.com/data/prdatasets/isolet5.zip';
+% Load zipped data from prtools website.
+url1 = 'http://prtools.tudelft.nl/prdatasets/isolet1+2+3+4.zip';
+url2 = 'http://prtools.tudelft.nl/prdatasets/isolet5.zip';
 [a,b] = pr_download_uci('ISOLET',{url1,url2});
 a = setname(a,'Isolet');
Index: prdatasets/musk1.m
===================================================================
--- prdatasets/musk1.m	(revision 148)
+++ prdatasets/musk1.m	(revision 150)
@@ -15,5 +15,5 @@
 %also MULTI_LABELING
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %DATASETS, MULTI_LABELING, CHANGELABLIST
 
@@ -21,6 +21,6 @@
 
 % UCI data is Z-compressed. No Matlab command foud for uncompressing.
-% Load zipped data from 37steps.
-a = pr_download_uci('Musk+(Version+1)','http://37steps.com/data/prdatasets/musk1.zip');
+% Load zipped data from prtools website.
+a = pr_download_uci('Musk+(Version+1)','http://prtools.tudelft.nl/prdatasets/musk1.zip');
 a = setlablistnames(a,'Bag Label',1);
 a = feat2lab(a,1,'Bag Index');
Index: prdatasets/musk2.m
===================================================================
--- prdatasets/musk2.m	(revision 148)
+++ prdatasets/musk2.m	(revision 150)
@@ -15,5 +15,5 @@
 %also MULTI_LABELING
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 %DATASETS, MULTI_LABELING, CHANGELABLIST
 
@@ -21,6 +21,6 @@
 
 % UCI data is Z-compressed. No Matlab command foud for uncompressing.
-% Load zipped data from 37steps.
-a = pr_download_uci('Musk+(Version+2)','http://37steps.com/data/prdatasets/musk2.zip',[],[],5);
+% Load zipped data from prtools website.
+a = pr_download_uci('Musk+(Version+2)','http://prtools.tudelft.nl/prdatasets/musk2.zip',[],[],5);
 a = setlablistnames(a,'Bag Label',1);
 a = feat2lab(a,1,'Bag Index');
Index: prdatasets/pageblocks.m
===================================================================
--- prdatasets/pageblocks.m	(revision 148)
+++ prdatasets/pageblocks.m	(revision 150)
@@ -10,10 +10,10 @@
 %publications that make use of this dataset.
 %
-%SEE ALSO <a href="http://37steps.com/prtools">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
+%SEE ALSO <a href="http://prtools.tudelft.nl/prtools/">PRTools Guide</a>, <a href="http://archive.ics.uci.edu/ml/">UCI Website</a>
 
 function a = pageblocks
 
 % UCI data is Z-compressed. No Matlab command foud for uncompressing.
-% Load zipped data from 37steps.
-a = pr_download_uci('Page+Blocks+Classification','http://37steps.com/data/prdatasets/page-blocks.zip',[],[],[],[],[],' ');
+% Load zipped data from prtools website.
+a = pr_download_uci('Page+Blocks+Classification','http://prtools.tudelft.nl/prdatasets/page-blocks.zip',[],[],[],[],[],' ');
 a = setname(a,'Page Blocks');